Data exploration
================

These three tutorials show how to perform data exploration with Gammapy, providing an introduction to the CTA,
H.E.S.S. and Fermi-LAT data and instrument response functions (IRFs). You will be able to explore and filter
event lists according to different criteria, as well as to get a quick look of the multidimensional IRFs files.
